"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMetricsMonitor = void 0;
const prom_client_1 = require("prom-client");
const memoizee_1 = __importDefault(require("memoizee"));
const events = __importStar(require("./metric-events"));
const events_1 = require("./types/events");
const date_fns_1 = require("date-fns");
const metrics_1 = require("./util/metrics");
class MetricsMonitor {
    constructor() { }
    async startMonitoring(config, stores, version, eventBus, instanceStatsService, schedulerService, db) {
        if (!config.server.serverMetrics) {
            return Promise.resolve();
        }
        const { eventStore, environmentStore } = stores;
        const { flagResolver } = config;
        const cachedEnvironments = (0, memoizee_1.default)(async () => environmentStore.getAll(), {
            promise: true,
            maxAge: (0, date_fns_1.hoursToMilliseconds)(1),
        });
        (0, prom_client_1.collectDefaultMetrics)();
        const requestDuration = (0, metrics_1.createSummary)({
            name: 'http_request_duration_milliseconds',
            help: 'App response time',
            labelNames: ['path', 'method', 'status', 'appName'],
            percentiles: [0.1, 0.5, 0.9, 0.95, 0.99],
            maxAgeSeconds: 600,
            ageBuckets: 5,
        });
        const schedulerDuration = (0, metrics_1.createSummary)({
            name: 'scheduler_duration_seconds',
            help: 'Scheduler duration time',
            labelNames: ['jobId'],
            percentiles: [0.1, 0.5, 0.9, 0.95, 0.99],
            maxAgeSeconds: 600,
            ageBuckets: 5,
        });
        const dbDuration = (0, metrics_1.createSummary)({
            name: 'db_query_duration_seconds',
            help: 'DB query duration time',
            labelNames: ['store', 'action'],
            percentiles: [0.1, 0.5, 0.9, 0.95, 0.99],
            maxAgeSeconds: 600,
            ageBuckets: 5,
        });
        const functionDuration = (0, metrics_1.createSummary)({
            name: 'function_duration_seconds',
            help: 'Function duration time',
            labelNames: ['functionName', 'className'],
            percentiles: [0.1, 0.5, 0.9, 0.95, 0.99],
            maxAgeSeconds: 600,
            ageBuckets: 5,
        });
        const featureFlagUpdateTotal = (0, metrics_1.createCounter)({
            name: 'feature_toggle_update_total',
            help: 'Number of times a toggle has been updated. Environment label would be "n/a" when it is not available, e.g. when a feature flag is created.',
            labelNames: ['toggle', 'project', 'environment', 'environmentType'],
        });
        const featureFlagUsageTotal = (0, metrics_1.createCounter)({
            name: 'feature_toggle_usage_total',
            help: 'Number of times a feature flag has been used',
            labelNames: ['toggle', 'active', 'appName'],
        });
        const featureFlagsTotal = (0, metrics_1.createGauge)({
            name: 'feature_toggles_total',
            help: 'Number of feature flags',
            labelNames: ['version'],
        });
        const maxFeatureEnvironmentStrategies = (0, metrics_1.createGauge)({
            name: 'max_feature_environment_strategies',
            help: 'Maximum number of environment strategies in one feature',
            labelNames: ['feature', 'environment'],
        });
        const maxFeatureStrategies = (0, metrics_1.createGauge)({
            name: 'max_feature_strategies',
            help: 'Maximum number of strategies in one feature',
            labelNames: ['feature'],
        });
        const maxConstraintValues = (0, metrics_1.createGauge)({
            name: 'max_constraint_values',
            help: 'Maximum number of constraint values used in a single constraint',
            labelNames: ['feature', 'environment'],
        });
        const maxConstraintsPerStrategy = (0, metrics_1.createGauge)({
            name: 'max_strategy_constraints',
            help: 'Maximum number of constraints used on a single strategy',
            labelNames: ['feature', 'environment'],
        });
        const largestProjectEnvironment = (0, metrics_1.createGauge)({
            name: 'largest_project_environment_size',
            help: 'The largest project environment size (bytes) based on strategies, constraints, variants and parameters',
            labelNames: ['project', 'environment'],
        });
        const largestFeatureEnvironment = (0, metrics_1.createGauge)({
            name: 'largest_feature_environment_size',
            help: 'The largest feature environment size (bytes) base on strategies, constraints, variants and parameters',
            labelNames: ['feature', 'environment'],
        });
        const featureTogglesArchivedTotal = (0, metrics_1.createGauge)({
            name: 'feature_toggles_archived_total',
            help: 'Number of archived feature flags',
        });
        const usersTotal = (0, metrics_1.createGauge)({
            name: 'users_total',
            help: 'Number of users',
        });
        const serviceAccounts = (0, metrics_1.createGauge)({
            name: 'service_accounts_total',
            help: 'Number of service accounts',
        });
        const apiTokens = (0, metrics_1.createGauge)({
            name: 'api_tokens_total',
            help: 'Number of API tokens',
            labelNames: ['type'],
        });
        const enabledMetricsBucketsPreviousDay = (0, metrics_1.createGauge)({
            name: 'enabled_metrics_buckets_previous_day',
            help: 'Number of hourly enabled/disabled metric buckets in the previous day',
        });
        const variantMetricsBucketsPreviousDay = (0, metrics_1.createGauge)({
            name: 'variant_metrics_buckets_previous_day',
            help: 'Number of hourly variant metric buckets in the previous day',
        });
        const usersActive7days = (0, metrics_1.createGauge)({
            name: 'users_active_7',
            help: 'Number of users active in the last 7 days',
        });
        const usersActive30days = (0, metrics_1.createGauge)({
            name: 'users_active_30',
            help: 'Number of users active in the last 30 days',
        });
        const usersActive60days = (0, metrics_1.createGauge)({
            name: 'users_active_60',
            help: 'Number of users active in the last 60 days',
        });
        const usersActive90days = (0, metrics_1.createGauge)({
            name: 'users_active_90',
            help: 'Number of users active in the last 90 days',
        });
        const projectsTotal = (0, metrics_1.createGauge)({
            name: 'projects_total',
            help: 'Number of projects',
            labelNames: ['mode'],
        });
        const environmentsTotal = (0, metrics_1.createGauge)({
            name: 'environments_total',
            help: 'Number of environments',
        });
        const groupsTotal = (0, metrics_1.createGauge)({
            name: 'groups_total',
            help: 'Number of groups',
        });
        const rolesTotal = (0, metrics_1.createGauge)({
            name: 'roles_total',
            help: 'Number of roles',
        });
        const customRootRolesTotal = (0, metrics_1.createGauge)({
            name: 'custom_root_roles_total',
            help: 'Number of custom root roles',
        });
        const customRootRolesInUseTotal = (0, metrics_1.createGauge)({
            name: 'custom_root_roles_in_use_total',
            help: 'Number of custom root roles in use',
        });
        const segmentsTotal = (0, metrics_1.createGauge)({
            name: 'segments_total',
            help: 'Number of segments',
        });
        const contextTotal = (0, metrics_1.createGauge)({
            name: 'context_total',
            help: 'Number of context',
        });
        const strategiesTotal = (0, metrics_1.createGauge)({
            name: 'strategies_total',
            help: 'Number of strategies',
        });
        const clientAppsTotal = (0, metrics_1.createGauge)({
            name: 'client_apps_total',
            help: 'Number of registered client apps aggregated by range by last seen',
            labelNames: ['range'],
        });
        const samlEnabled = (0, metrics_1.createGauge)({
            name: 'saml_enabled',
            help: 'Whether SAML is enabled',
        });
        const oidcEnabled = (0, metrics_1.createGauge)({
            name: 'oidc_enabled',
            help: 'Whether OIDC is enabled',
        });
        const clientSdkVersionUsage = (0, metrics_1.createCounter)({
            name: 'client_sdk_versions',
            help: 'Which sdk versions are being used',
            labelNames: [
                'sdk_name',
                'sdk_version',
                'platform_name',
                'platform_version',
                'yggdrasil_version',
                'spec_version',
            ],
        });
        const productionChanges30 = (0, metrics_1.createGauge)({
            name: 'production_changes_30',
            help: 'Changes made to production environment last 30 days',
            labelNames: ['environment'],
        });
        const productionChanges60 = (0, metrics_1.createGauge)({
            name: 'production_changes_60',
            help: 'Changes made to production environment last 60 days',
            labelNames: ['environment'],
        });
        const productionChanges90 = (0, metrics_1.createGauge)({
            name: 'production_changes_90',
            help: 'Changes made to production environment last 90 days',
            labelNames: ['environment'],
        });
        const rateLimits = (0, metrics_1.createGauge)({
            name: 'rate_limits',
            help: 'Rate limits (per minute) for METHOD/ENDPOINT pairs',
            labelNames: ['endpoint', 'method'],
        });
        const featureCreatedByMigration = (0, metrics_1.createCounter)({
            name: 'feature_created_by_migration_count',
            help: 'Feature createdBy migration count',
        });
        const eventCreatedByMigration = (0, metrics_1.createCounter)({
            name: 'event_created_by_migration_count',
            help: 'Event createdBy migration count',
        });
        const proxyRepositoriesCreated = (0, metrics_1.createCounter)({
            name: 'proxy_repositories_created',
            help: 'Proxy repositories created',
        });
        const frontendApiRepositoriesCreated = (0, metrics_1.createCounter)({
            name: 'frontend_api_repositories_created',
            help: 'Frontend API repositories created',
        });
        const mapFeaturesForClientDuration = (0, metrics_1.createHistogram)({
            name: 'map_features_for_client_duration',
            help: 'Duration of mapFeaturesForClient function',
        });
        const featureLifecycleStageDuration = (0, metrics_1.createGauge)({
            name: 'feature_lifecycle_stage_duration',
            labelNames: ['stage', 'project_id'],
            help: 'Duration of feature lifecycle stages',
        });
        const onboardingDuration = (0, metrics_1.createGauge)({
            name: 'onboarding_duration',
            labelNames: ['event'],
            help: 'firstLogin, secondLogin, firstFeatureFlag, firstPreLive, firstLive from first user creation',
        });
        const projectOnboardingDuration = (0, metrics_1.createGauge)({
            name: 'project_onboarding_duration',
            labelNames: ['event', 'project'],
            help: 'firstFeatureFlag, firstPreLive, firstLive from project creation',
        });
        const featureLifecycleStageCountByProject = (0, metrics_1.createGauge)({
            name: 'feature_lifecycle_stage_count_by_project',
            help: 'Count features in a given stage by project id',
            labelNames: ['stage', 'project_id'],
        });
        const featureLifecycleStageEnteredCounter = (0, metrics_1.createCounter)({
            name: 'feature_lifecycle_stage_entered',
            help: 'Count how many features entered a given stage',
            labelNames: ['stage'],
        });
        const projectActionsCounter = (0, metrics_1.createCounter)({
            name: 'project_actions_count',
            help: 'Count project actions',
            labelNames: ['action'],
        });
        const projectEnvironmentsDisabled = (0, metrics_1.createCounter)({
            name: 'project_environments_disabled',
            help: 'How many "environment disabled" events we have received for each project',
            labelNames: ['project_id'],
        });
        const orphanedTokensTotal = (0, metrics_1.createGauge)({
            name: 'orphaned_api_tokens_total',
            help: 'Number of API tokens without a project',
        });
        const orphanedTokensActive = (0, metrics_1.createGauge)({
            name: 'orphaned_api_tokens_active',
            help: 'Number of API tokens without a project, last seen within 3 months',
        });
        const legacyTokensTotal = (0, metrics_1.createGauge)({
            name: 'legacy_api_tokens_total',
            help: 'Number of API tokens with v1 format',
        });
        const legacyTokensActive = (0, metrics_1.createGauge)({
            name: 'legacy_api_tokens_active',
            help: 'Number of API tokens with v1 format, last seen within 3 months',
        });
        const exceedsLimitErrorCounter = (0, metrics_1.createCounter)({
            name: 'exceeds_limit_error',
            help: 'The number of exceeds limit errors registered by this instance.',
            labelNames: ['resource', 'limit'],
        });
        const requestOriginCounter = (0, metrics_1.createCounter)({
            name: 'request_origin_counter',
            help: 'Number of authenticated requests, including origin information.',
            labelNames: ['type', 'method', 'source'],
        });
        const resourceLimit = (0, metrics_1.createGauge)({
            name: 'resource_limit',
            help: 'The maximum number of resources allowed.',
            labelNames: ['resource'],
        });
        const addonEventsHandledCounter = (0, metrics_1.createCounter)({
            name: 'addon_events_handled',
            help: 'Events handled by addons and the result.',
            labelNames: ['result', 'destination'],
        });
        async function collectStaticCounters() {
            try {
                const stats = await instanceStatsService.getStats();
                const [maxStrategies, maxEnvironmentStrategies, maxConstraintValuesResult, maxConstraintsPerStrategyResult, stageCountByProjectResult, stageDurationByProject, largestProjectEnvironments, largestFeatureEnvironments, deprecatedTokens, instanceOnboardingMetrics, projectsOnboardingMetrics,] = await Promise.all([
                    stores.featureStrategiesReadModel.getMaxFeatureStrategies(),
                    stores.featureStrategiesReadModel.getMaxFeatureEnvironmentStrategies(),
                    stores.featureStrategiesReadModel.getMaxConstraintValues(),
                    stores.featureStrategiesReadModel.getMaxConstraintsPerStrategy(),
                    stores.featureLifecycleReadModel.getStageCountByProject(),
                    stores.featureLifecycleReadModel.getAllWithStageDuration(),
                    stores.largestResourcesReadModel.getLargestProjectEnvironments(1),
                    stores.largestResourcesReadModel.getLargestFeatureEnvironments(1),
                    stores.apiTokenStore.countDeprecatedTokens(),
                    flagResolver.isEnabled('onboardingMetrics')
                        ? stores.onboardingReadModel.getInstanceOnboardingMetrics()
                        : Promise.resolve({}),
                    flagResolver.isEnabled('onboardingMetrics')
                        ? stores.onboardingReadModel.getProjectsOnboardingMetrics()
                        : Promise.resolve([]),
                ]);
                featureFlagsTotal.reset();
                featureFlagsTotal.labels({ version }).set(stats.featureToggles);
                featureTogglesArchivedTotal.reset();
                featureTogglesArchivedTotal.set(stats.archivedFeatureToggles);
                usersTotal.reset();
                usersTotal.set(stats.users);
                serviceAccounts.reset();
                serviceAccounts.set(stats.serviceAccounts);
                stageDurationByProject.forEach((stage) => {
                    featureLifecycleStageDuration
                        .labels({
                        stage: stage.stage,
                        project_id: stage.project,
                    })
                        .set(stage.duration);
                });
                eventBus.on(events.STAGE_ENTERED, (entered) => {
                    featureLifecycleStageEnteredCounter.increment({
                        stage: entered.stage,
                    });
                });
                eventBus.on(events.EXCEEDS_LIMIT, ({ resource, limit, }) => {
                    exceedsLimitErrorCounter.increment({ resource, limit });
                });
                featureLifecycleStageCountByProject.reset();
                stageCountByProjectResult.forEach((stageResult) => featureLifecycleStageCountByProject
                    .labels({
                    project_id: stageResult.project,
                    stage: stageResult.stage,
                })
                    .set(stageResult.count));
                apiTokens.reset();
                for (const [type, value] of stats.apiTokens) {
                    apiTokens.labels({ type }).set(value);
                }
                orphanedTokensTotal.reset();
                orphanedTokensTotal.set(deprecatedTokens.orphanedTokens);
                orphanedTokensActive.reset();
                orphanedTokensActive.set(deprecatedTokens.activeOrphanedTokens);
                legacyTokensTotal.reset();
                legacyTokensTotal.set(deprecatedTokens.legacyTokens);
                legacyTokensActive.reset();
                legacyTokensActive.set(deprecatedTokens.activeLegacyTokens);
                if (maxEnvironmentStrategies) {
                    maxFeatureEnvironmentStrategies.reset();
                    maxFeatureEnvironmentStrategies
                        .labels({
                        environment: maxEnvironmentStrategies.environment,
                        feature: maxEnvironmentStrategies.feature,
                    })
                        .set(maxEnvironmentStrategies.count);
                }
                if (maxStrategies) {
                    maxFeatureStrategies.reset();
                    maxFeatureStrategies
                        .labels({ feature: maxStrategies.feature })
                        .set(maxStrategies.count);
                }
                if (maxConstraintValuesResult) {
                    maxConstraintValues.reset();
                    maxConstraintValues
                        .labels({
                        environment: maxConstraintValuesResult.environment,
                        feature: maxConstraintValuesResult.feature,
                    })
                        .set(maxConstraintValuesResult.count);
                }
                if (maxConstraintsPerStrategyResult) {
                    maxConstraintsPerStrategy.reset();
                    maxConstraintsPerStrategy
                        .labels({
                        environment: maxConstraintsPerStrategyResult.environment,
                        feature: maxConstraintsPerStrategyResult.feature,
                    })
                        .set(maxConstraintsPerStrategyResult.count);
                }
                if (largestProjectEnvironments.length > 0) {
                    const projectEnvironment = largestProjectEnvironments[0];
                    largestProjectEnvironment.reset();
                    largestProjectEnvironment
                        .labels({
                        project: projectEnvironment.project,
                        environment: projectEnvironment.environment,
                    })
                        .set(projectEnvironment.size);
                }
                if (largestFeatureEnvironments.length > 0) {
                    const featureEnvironment = largestFeatureEnvironments[0];
                    largestFeatureEnvironment.reset();
                    largestFeatureEnvironment
                        .labels({
                        feature: featureEnvironment.feature,
                        environment: featureEnvironment.environment,
                    })
                        .set(featureEnvironment.size);
                }
                Object.keys(instanceOnboardingMetrics).forEach((key) => {
                    if (Number.isInteger(instanceOnboardingMetrics[key])) {
                        onboardingDuration
                            .labels({
                            event: key,
                        })
                            .set(instanceOnboardingMetrics[key]);
                    }
                });
                projectsOnboardingMetrics.forEach(({ project, ...projectMetrics }) => {
                    Object.keys(projectMetrics).forEach((key) => {
                        if (Number.isInteger(projectMetrics[key])) {
                            projectOnboardingDuration
                                .labels({ event: key, project })
                                .set(projectMetrics[key]);
                        }
                    });
                });
                for (const [resource, limit] of Object.entries(config.resourceLimits)) {
                    resourceLimit.labels({ resource }).set(limit);
                }
                enabledMetricsBucketsPreviousDay.reset();
                enabledMetricsBucketsPreviousDay.set(stats.previousDayMetricsBucketsCount.enabledCount);
                variantMetricsBucketsPreviousDay.reset();
                variantMetricsBucketsPreviousDay.set(stats.previousDayMetricsBucketsCount.variantCount);
                usersActive7days.reset();
                usersActive7days.set(stats.activeUsers.last7);
                usersActive30days.reset();
                usersActive30days.set(stats.activeUsers.last30);
                usersActive60days.reset();
                usersActive60days.set(stats.activeUsers.last60);
                usersActive90days.reset();
                usersActive90days.set(stats.activeUsers.last90);
                productionChanges30.reset();
                productionChanges30.set(stats.productionChanges.last30);
                productionChanges60.reset();
                productionChanges60.set(stats.productionChanges.last60);
                productionChanges90.reset();
                productionChanges90.set(stats.productionChanges.last90);
                projectsTotal.reset();
                stats.projects.forEach((projectStat) => {
                    projectsTotal
                        .labels({ mode: projectStat.mode })
                        .set(projectStat.count);
                });
                environmentsTotal.reset();
                environmentsTotal.set(stats.environments);
                groupsTotal.reset();
                groupsTotal.set(stats.groups);
                rolesTotal.reset();
                rolesTotal.set(stats.roles);
                customRootRolesTotal.reset();
                customRootRolesTotal.set(stats.customRootRoles);
                customRootRolesInUseTotal.reset();
                customRootRolesInUseTotal.set(stats.customRootRolesInUse);
                segmentsTotal.reset();
                segmentsTotal.set(stats.segments);
                contextTotal.reset();
                contextTotal.set(stats.contextFields);
                strategiesTotal.reset();
                strategiesTotal.set(stats.strategies);
                samlEnabled.reset();
                samlEnabled.set(stats.SAMLenabled ? 1 : 0);
                oidcEnabled.reset();
                oidcEnabled.set(stats.OIDCenabled ? 1 : 0);
                clientAppsTotal.reset();
                stats.clientApps.forEach(({ range, count }) => clientAppsTotal.labels({ range }).set(count));
                rateLimits.reset();
                rateLimits
                    .labels({
                    endpoint: '/api/client/metrics',
                    method: 'POST',
                })
                    .set(config.metricsRateLimiting.clientMetricsMaxPerMinute);
                rateLimits
                    .labels({
                    endpoint: '/api/client/register',
                    method: 'POST',
                })
                    .set(config.metricsRateLimiting.clientRegisterMaxPerMinute);
                rateLimits
                    .labels({
                    endpoint: '/api/frontend/metrics',
                    method: 'POST',
                })
                    .set(config.metricsRateLimiting.frontendMetricsMaxPerMinute);
                rateLimits
                    .labels({
                    endpoint: '/api/frontend/register',
                    method: 'POST',
                })
                    .set(config.metricsRateLimiting.frontendRegisterMaxPerMinute);
                rateLimits
                    .labels({
                    endpoint: '/api/admin/user-admin',
                    method: 'POST',
                })
                    .set(config.rateLimiting.createUserMaxPerMinute);
                rateLimits
                    .labels({
                    endpoint: '/auth/simple',
                    method: 'POST',
                })
                    .set(config.rateLimiting.simpleLoginMaxPerMinute);
                rateLimits
                    .labels({
                    endpoint: '/auth/reset/password-email',
                    method: 'POST',
                })
                    .set(config.rateLimiting.passwordResetMaxPerMinute);
                rateLimits
                    .labels({
                    endpoint: '/api/signal-endpoint/:name',
                    method: 'POST',
                })
                    .set(config.rateLimiting.callSignalEndpointMaxPerSecond * 60);
            }
            catch (e) { }
        }
        await schedulerService.schedule(collectStaticCounters.bind(this), (0, date_fns_1.hoursToMilliseconds)(2), 'collectStaticCounters', 0);
        eventBus.on(events.REQUEST_TIME, ({ path, method, time, statusCode, appName }) => {
            requestDuration
                .labels({
                path,
                method,
                status: statusCode,
                appName,
            })
                .observe(time);
        });
        eventBus.on(events.SCHEDULER_JOB_TIME, ({ jobId, time }) => {
            schedulerDuration.labels(jobId).observe(time);
        });
        eventBus.on(events.FUNCTION_TIME, ({ functionName, className, time }) => {
            functionDuration
                .labels({
                functionName,
                className,
            })
                .observe(time);
        });
        eventBus.on(events.EVENTS_CREATED_BY_PROCESSED, ({ updated }) => {
            eventCreatedByMigration.inc(updated);
        });
        eventBus.on(events.FEATURES_CREATED_BY_PROCESSED, ({ updated }) => {
            featureCreatedByMigration.inc(updated);
        });
        eventBus.on(events.DB_TIME, ({ store, action, time }) => {
            dbDuration
                .labels({
                store,
                action,
            })
                .observe(time);
        });
        eventBus.on(events.PROXY_REPOSITORY_CREATED, () => {
            proxyRepositoriesCreated.inc();
        });
        eventBus.on(events.FRONTEND_API_REPOSITORY_CREATED, () => {
            frontendApiRepositoriesCreated.inc();
        });
        eventBus.on(events.PROXY_FEATURES_FOR_TOKEN_TIME, ({ duration }) => {
            mapFeaturesForClientDuration.observe(duration);
        });
        events.onMetricEvent(eventBus, events.REQUEST_ORIGIN, ({ type, method, source }) => {
            if (flagResolver.isEnabled('originMiddleware')) {
                requestOriginCounter.increment({ type, method, source });
            }
        });
        eventStore.on(events_1.FEATURE_CREATED, ({ featureName, project }) => {
            featureFlagUpdateTotal.increment({
                toggle: featureName,
                project,
                environment: 'n/a',
                environmentType: 'n/a',
            });
        });
        eventStore.on(events_1.FEATURE_VARIANTS_UPDATED, ({ featureName, project }) => {
            featureFlagUpdateTotal.increment({
                toggle: featureName,
                project,
                environment: 'n/a',
                environmentType: 'n/a',
            });
        });
        eventStore.on(events_1.FEATURE_METADATA_UPDATED, ({ featureName, project }) => {
            featureFlagUpdateTotal.increment({
                toggle: featureName,
                project,
                environment: 'n/a',
                environmentType: 'n/a',
            });
        });
        eventStore.on(events_1.FEATURE_UPDATED, ({ featureName, project }) => {
            featureFlagUpdateTotal.increment({
                toggle: featureName,
                project,
                environment: 'default',
                environmentType: 'production',
            });
        });
        eventStore.on(events_1.FEATURE_STRATEGY_ADD, async ({ featureName, project, environment }) => {
            const environmentType = await this.resolveEnvironmentType(environment, cachedEnvironments);
            featureFlagUpdateTotal.increment({
                toggle: featureName,
                project,
                environment,
                environmentType,
            });
        });
        eventStore.on(events_1.FEATURE_STRATEGY_REMOVE, async ({ featureName, project, environment }) => {
            const environmentType = await this.resolveEnvironmentType(environment, cachedEnvironments);
            featureFlagUpdateTotal.increment({
                toggle: featureName,
                project,
                environment,
                environmentType,
            });
        });
        eventStore.on(events_1.FEATURE_STRATEGY_UPDATE, async ({ featureName, project, environment }) => {
            const environmentType = await this.resolveEnvironmentType(environment, cachedEnvironments);
            featureFlagUpdateTotal.increment({
                toggle: featureName,
                project,
                environment,
                environmentType,
            });
        });
        eventStore.on(events_1.FEATURE_ENVIRONMENT_DISABLED, async ({ featureName, project, environment }) => {
            const environmentType = await this.resolveEnvironmentType(environment, cachedEnvironments);
            featureFlagUpdateTotal.increment({
                toggle: featureName,
                project,
                environment,
                environmentType,
            });
        });
        eventStore.on(events_1.FEATURE_ENVIRONMENT_ENABLED, async ({ featureName, project, environment }) => {
            const environmentType = await this.resolveEnvironmentType(environment, cachedEnvironments);
            featureFlagUpdateTotal.increment({
                toggle: featureName,
                project,
                environment,
                environmentType,
            });
        });
        eventStore.on(events_1.FEATURE_ARCHIVED, ({ featureName, project }) => {
            featureFlagUpdateTotal.increment({
                toggle: featureName,
                project,
                environment: 'n/a',
                environmentType: 'n/a',
            });
        });
        eventStore.on(events_1.FEATURE_REVIVED, ({ featureName, project }) => {
            featureFlagUpdateTotal.increment({
                toggle: featureName,
                project,
                environment: 'n/a',
                environmentType: 'n/a',
            });
        });
        eventStore.on(events_1.PROJECT_CREATED, () => {
            projectActionsCounter.increment({ action: events_1.PROJECT_CREATED });
        });
        eventStore.on(events_1.PROJECT_ARCHIVED, () => {
            projectActionsCounter.increment({ action: events_1.PROJECT_ARCHIVED });
        });
        eventStore.on(events_1.PROJECT_REVIVED, () => {
            projectActionsCounter.increment({ action: events_1.PROJECT_REVIVED });
        });
        eventStore.on(events_1.PROJECT_DELETED, () => {
            projectActionsCounter.increment({ action: events_1.PROJECT_DELETED });
        });
        const logger = config.getLogger('metrics.ts');
        eventBus.on(events_1.CLIENT_METRICS, (metrics) => {
            try {
                for (const metric of metrics) {
                    featureFlagUsageTotal.increment({
                        toggle: metric.featureName,
                        active: 'true',
                        appName: metric.appName,
                    }, metric.yes);
                    featureFlagUsageTotal.increment({
                        toggle: metric.featureName,
                        active: 'false',
                        appName: metric.appName,
                    }, metric.no);
                }
            }
            catch (e) {
                logger.warn('Metrics registration failed', e);
            }
        });
        eventStore.on(events_1.CLIENT_REGISTER, (heartbeatEvent) => {
            if (!heartbeatEvent.sdkName || !heartbeatEvent.sdkVersion) {
                return;
            }
            if (flagResolver.isEnabled('extendedMetrics')) {
                clientSdkVersionUsage.increment({
                    sdk_name: heartbeatEvent.sdkName,
                    sdk_version: heartbeatEvent.sdkVersion,
                    platform_name: heartbeatEvent.metadata?.platformName ?? 'not-set',
                    platform_version: heartbeatEvent.metadata?.platformVersion ?? 'not-set',
                    yggdrasil_version: heartbeatEvent.metadata?.yggdrasilVersion ?? 'not-set',
                    spec_version: heartbeatEvent.metadata?.specVersion ?? 'not-set',
                });
            }
            else {
                clientSdkVersionUsage.increment({
                    sdk_name: heartbeatEvent.sdkName,
                    sdk_version: heartbeatEvent.sdkVersion,
                    platform_name: 'not-set',
                    platform_version: 'not-set',
                    yggdrasil_version: 'not-set',
                    spec_version: 'not-set',
                });
            }
        });
        eventStore.on(events_1.PROJECT_ENVIRONMENT_REMOVED, ({ project }) => {
            projectEnvironmentsDisabled.increment({ project_id: project });
        });
        eventBus.on(events.ADDON_EVENTS_HANDLED, ({ result, destination }) => {
            addonEventsHandledCounter.increment({ result, destination });
        });
        await this.configureDbMetrics(db, eventBus, schedulerService, stores.settingStore);
        return Promise.resolve();
    }
    async configureDbMetrics(db, eventBus, schedulerService, settingStore) {
        if (db?.client) {
            const dbPoolMin = (0, metrics_1.createGauge)({
                name: 'db_pool_min',
                help: 'Minimum DB pool size',
            });
            dbPoolMin.set(db.client.pool.min);
            const dbPoolMax = (0, metrics_1.createGauge)({
                name: 'db_pool_max',
                help: 'Maximum DB pool size',
            });
            dbPoolMax.set(db.client.pool.max);
            const dbPoolFree = (0, metrics_1.createGauge)({
                name: 'db_pool_free',
                help: 'Current free connections in DB pool',
            });
            const dbPoolUsed = (0, metrics_1.createGauge)({
                name: 'db_pool_used',
                help: 'Current connections in use in DB pool',
            });
            const dbPoolPendingCreates = (0, metrics_1.createGauge)({
                name: 'db_pool_pending_creates',
                help: 'how many asynchronous create calls are running in DB pool',
            });
            const dbPoolPendingAcquires = (0, metrics_1.createGauge)({
                name: 'db_pool_pending_acquires',
                help: 'how many acquires are waiting for a resource to be released in DB pool',
            });
            eventBus.on(events_1.DB_POOL_UPDATE, (data) => {
                dbPoolFree.set(data.free);
                dbPoolUsed.set(data.used);
                dbPoolPendingCreates.set(data.pendingCreates);
                dbPoolPendingAcquires.set(data.pendingAcquires);
            });
            await schedulerService.schedule(async () => this.registerPoolMetrics.bind(this, db.client.pool, eventBus), (0, date_fns_1.minutesToMilliseconds)(1), 'registerPoolMetrics', 0);
            const postgresVersion = await settingStore.postgresVersion();
            const database_version = (0, metrics_1.createGauge)({
                name: 'postgres_version',
                help: 'Which version of postgres is running (SHOW server_version)',
                labelNames: ['version'],
            });
            database_version.labels({ version: postgresVersion }).set(1);
        }
    }
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    registerPoolMetrics(pool, eventBus) {
        try {
            eventBus.emit(events_1.DB_POOL_UPDATE, {
                used: pool.numUsed(),
                free: pool.numFree(),
                pendingCreates: pool.numPendingCreates(),
                pendingAcquires: pool.numPendingAcquires(),
            });
            // eslint-disable-next-line no-empty
        }
        catch (e) { }
    }
    async resolveEnvironmentType(environment, cachedEnvironments) {
        const environments = await cachedEnvironments();
        const env = environments.find((e) => e.name === environment);
        if (env) {
            return env.type;
        }
        else {
            return 'unknown';
        }
    }
}
exports.default = MetricsMonitor;
function createMetricsMonitor() {
    return new MetricsMonitor();
}
exports.createMetricsMonitor = createMetricsMonitor;
module.exports = {
    createMetricsMonitor,
};
//# sourceMappingURL=metrics.js.map