"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createFeatureSchema = void 0;
const tag_schema_1 = require("./tag-schema");
exports.createFeatureSchema = {
    $id: '#/components/schemas/createFeatureSchema',
    type: 'object',
    description: 'Data used to create a new feature flag.',
    required: ['name'],
    properties: {
        name: {
            type: 'string',
            example: 'disable-comments',
            description: 'Unique feature name',
        },
        type: {
            enum: [
                'experiment',
                'kill-switch',
                'release',
                'operational',
                'permission',
            ],
            example: 'release',
            description: "The feature flag's [type](https://docs.getunleash.io/reference/feature-toggle-types). One of experiment, kill-switch, release, operational, or permission",
        },
        description: {
            type: 'string',
            nullable: true,
            example: 'Controls disabling of the comments section in case of an incident',
            description: 'Detailed description of the feature',
        },
        impressionData: {
            type: 'boolean',
            example: false,
            description: '`true` if the impression data collection is enabled for the feature, otherwise `false`.',
        },
        tags: {
            type: 'array',
            description: 'Tags to add to the feature.',
            items: {
                $ref: '#/components/schemas/tagSchema',
            },
        },
    },
    components: {
        schemas: {
            tagSchema: tag_schema_1.tagSchema,
        },
    },
};
//# sourceMappingURL=create-feature-schema.js.map